@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package secrets
@@ -14,8 +14,12 @@ type ExternalPluginProvider struct {
 	// plugin is the commonplugin to be executed by this secret
 	plugin commonplugins.SecretsPlugin
 
-	// name of the plugin and also the executable
-	name string
+	// pluginName refers to the provider parameter of the secret block
+	// and is here mainly for debugging purposes
+	pluginName string
+
+	// secretName is the secret block name executing the plugin
+	secretName string
 
 	// path is the secret location used in Fetch
 	path string
@@ -26,26 +30,27 @@ type Response struct {
 	Error  *string           `json:"error,omitempty"`
 }
 
-func NewExternalPluginProvider(plugin commonplugins.SecretsPlugin, name string, path string) *ExternalPluginProvider {
+func NewExternalPluginProvider(plugin commonplugins.SecretsPlugin, pluginName, secretName, path string) *ExternalPluginProvider {
 	return &ExternalPluginProvider{
-		plugin: plugin,
-		name:   name,
-		path:   path,
+		plugin:     plugin,
+		pluginName: pluginName,
+		secretName: secretName,
+		path:       path,
 	}
 }
 
 func (p *ExternalPluginProvider) Fetch(ctx context.Context) (map[string]string, error) {
 	resp, err := p.plugin.Fetch(ctx, p.path)
 	if err != nil {
-		return nil, fmt.Errorf("failed to fetch secret from plugin %s: %w", p.name, err)
+		return nil, fmt.Errorf("failed executing plugin %q for secret %q: %w", p.pluginName, p.secretName, err)
 	}
 	if resp.Error != nil {
-		return nil, fmt.Errorf("error returned from secret plugin %s: %s", p.name, *resp.Error)
+		return nil, fmt.Errorf("provider %q for secret %q response contained error: %q", p.pluginName, p.secretName, *resp.Error)
 	}
 
 	formatted := make(map[string]string, len(resp.Result))
 	for k, v := range resp.Result {
-		formatted[fmt.Sprintf("secret.%s.%s", p.name, k)] = v
+		formatted[fmt.Sprintf("secret.%s.%s", p.secretName, k)] = v
 	}
 
 	return formatted, nil
