@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package fingerprint
@@ -14,3 +14,6 @@ type BridgeFingerprint struct {
 func NewBridgeFingerprint(logger log.Logger) Fingerprint {
 	return &BridgeFingerprint{logger: logger}
 }
+
+// Reload is a no-op but implements ReloadableFingerprint
+func (f *BridgeFingerprint) Reload() {}
