@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package agent
@@ -13,6 +13,7 @@ import (
 	"sort"
 	"time"
 
+	"github.com/go-viper/mapstructure/v2"
 	"github.com/hashicorp/hcl"
 	"github.com/hashicorp/hcl/hcl/ast"
 	client "github.com/hashicorp/nomad/client/config"
@@ -20,7 +21,6 @@ import (
 	"github.com/hashicorp/nomad/helper/ipaddr"
 	"github.com/hashicorp/nomad/nomad/structs"
 	"github.com/hashicorp/nomad/nomad/structs/config"
-	"github.com/mitchellh/mapstructure"
 )
 
 // ParseConfigFile returns an agent.Config from parsed from a file.
@@ -244,6 +244,12 @@ func ParseConfigFile(path string) (*Config, error) {
 			fmt.Sprintf("audit.sink.%d", i), &sink.RotateDuration, &sink.RotateDurationHCL, nil})
 	}
 
+	// Add fingerprint retry_interval for time.Duration parsing
+	for _, fp := range c.Client.Fingerprinters {
+		tds = append(tds, durationConversionMap{
+			fmt.Sprintf("client.fingerprint.%s.retry_interval", fp.Name), &fp.RetryInterval, &fp.RetryIntervalHCL, nil})
+	}
+
 	// convert strings to time.Durations
 	err = convertDurations(tds)
 	if err != nil {
@@ -374,6 +380,16 @@ func extraKeys(c *Config) error {
 	c.ExtraKeysHCL = slices.DeleteFunc(c.ExtraKeysHCL, func(s string) bool { return s == "vault" })
 	c.ExtraKeysHCL = slices.DeleteFunc(c.ExtraKeysHCL, func(s string) bool { return s == "consul" })
 
+	// The fingerprinter labels will be added to the ExtraKeysHCL slice by
+	// hcl.Decode, so we need to remove them here.
+	//
+	// When parsing JSON, each block will also add "fingerprint" to the
+	// ExtraKeysHCL slice, so we need to remove that as well.
+	for _, p := range c.Client.Fingerprinters {
+		helper.RemoveEqualFold(&c.Client.ExtraKeysHCL, p.Name)
+		helper.RemoveEqualFold(&c.Client.ExtraKeysHCL, "fingerprint")
+	}
+
 	if len(c.ExtraKeysHCL) == 0 {
 		c.ExtraKeysHCL = nil
 	}
