@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package command
@@ -797,7 +797,7 @@ func (c *JobStatusCommand) outputFailedPlacements(failedEval *api.Evaluation) {
 
 		c.Ui.Output(fmt.Sprintf("Task Group %q:", tg))
 		metrics := failedEval.FailedTGAllocs[tg]
-		c.Ui.Output(formatAllocMetrics(metrics, false, "  "))
+		c.Ui.Output(formatAllocMetrics(metrics, c.Colorize(), false, "  "))
 		if i != len(sorted)-1 {
 			c.Ui.Output("")
 		}
