@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package nomad
@@ -131,7 +131,10 @@ func (d *Deployment) Fail(args *structs.DeploymentFailRequest, reply *structs.De
 	// Check namespace submit-job permissions
 	if aclObj, err := d.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(deploy.Namespace, acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(deploy.Namespace,
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityFailDeployment,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -178,7 +181,10 @@ func (d *Deployment) Pause(args *structs.DeploymentPauseRequest, reply *structs.
 	// Check namespace submit-job permissions
 	if aclObj, err := d.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(deploy.Namespace, acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(deploy.Namespace,
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityPauseDeployment,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -229,7 +235,10 @@ func (d *Deployment) Promote(args *structs.DeploymentPromoteRequest, reply *stru
 	// Check namespace submit-job permissions
 	if aclObj, err := d.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(deploy.Namespace, acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(deploy.Namespace,
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityPromoteDeployment,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -276,7 +285,10 @@ func (d *Deployment) Run(args *structs.DeploymentRunRequest, reply *structs.Depl
 	// Check namespace submit-job permissions
 	if aclObj, err := d.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(deploy.Namespace, acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(deploy.Namespace,
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityRegisterJob,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -323,7 +335,10 @@ func (d *Deployment) Unblock(args *structs.DeploymentUnblockRequest, reply *stru
 	// Check namespace submit-job permissions
 	if aclObj, err := d.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(deploy.Namespace, acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(deploy.Namespace,
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityUnblockDeployment,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -370,7 +385,10 @@ func (d *Deployment) Cancel(args *structs.DeploymentCancelRequest, reply *struct
 	// Check namespace submit-job permissions
 	if aclObj, err := d.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(deploy.Namespace, acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(deploy.Namespace,
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityCancelDeployment,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -422,7 +440,10 @@ func (d *Deployment) SetAllocHealth(args *structs.DeploymentAllocHealthRequest,
 	// Check namespace submit-job permissions
 	if aclObj, err := d.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(deploy.Namespace, acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(deploy.Namespace,
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilitySetAllocHealthDeployment,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
