@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package nomad
@@ -157,7 +157,7 @@ func (e *Encrypter) loadKeystore() error {
 
 	keyErrors := map[string]error{}
 
-	return filepath.Walk(e.keystorePath, func(path string, info fs.FileInfo, err error) error {
+	filepath.Walk(e.keystorePath, func(path string, info fs.FileInfo, err error) error {
 		if err != nil {
 			return fmt.Errorf("could not read path %s from keystore: %v", path, err)
 		}
@@ -186,8 +186,8 @@ func (e *Encrypter) loadKeystore() error {
 
 		key, err := e.loadKeyFromStore(path)
 		if err != nil {
-			keyErrors[id] = err
-			return fmt.Errorf("could not load key file %s from keystore: %w", path, err)
+			keyErrors[id] = fmt.Errorf("could not load key file %s from keystore: %w", path, err)
+			return nil
 		}
 		if key.Meta.KeyID != id {
 			return fmt.Errorf("root key ID %s must match key file %s", key.Meta.KeyID, path)
@@ -203,6 +203,16 @@ func (e *Encrypter) loadKeystore() error {
 		delete(keyErrors, id)
 		return nil
 	})
+
+	if len(keyErrors) == 0 {
+		return nil
+	}
+
+	var mErr multierror.Error
+	for _, err := range keyErrors {
+		mErr = *multierror.Append(&mErr, err)
+	}
+	return mErr.ErrorOrNil()
 }
 
 // IsReady blocks until all in-flight decrypt tasks are complete, or the context
