@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package nomad
@@ -105,11 +105,19 @@ func (j *Job) Register(args *structs.JobRegisterRequest, reply *structs.JobRegis
 		return structs.ErrPermissionDenied
 	}
 	defer metrics.MeasureSince([]string{"nomad", "job", "register"}, time.Now())
-
 	aclObj, err := j.srv.ResolveACL(args)
 	if err != nil {
 		return err
 	}
+
+	allowedPermissions := []string{acl.NamespaceCapabilityRegisterJob}
+
+	return j.doRegister(aclObj, allowedPermissions, args, reply)
+}
+
+// doRegister does the actual job registration, including any additional
+// permission checks, and after metrics have begun recording
+func (j *Job) doRegister(aclObj *acl.ACL, additionalAllowedPermissions []string, args *structs.JobRegisterRequest, reply *structs.JobRegisterResponse) error {
 	if ok, err := registrationsAreAllowed(aclObj, j.srv.State()); !ok || err != nil {
 		j.logger.Warn("job registration is currently disabled for non-management ACL")
 		return structs.ErrJobRegistrationDisabled
@@ -148,8 +156,9 @@ func (j *Job) Register(args *structs.JobRegisterRequest, reply *structs.JobRegis
 	// Set the warning message
 	reply.Warnings = helper.MergeMultierrorWarnings(warnings...)
 
+	permissions := append([]string{acl.NamespaceCapabilitySubmitJob}, additionalAllowedPermissions...)
 	// Check job submission permissions
-	if !aclObj.AllowNsOp(args.RequestNamespace(), acl.NamespaceCapabilitySubmitJob) {
+	if !aclObj.AllowNsOpAnyOf(args.RequestNamespace(), permissions...) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -297,12 +306,8 @@ func (j *Job) Register(args *structs.JobRegisterRequest, reply *structs.JobRegis
 		return err
 	}
 
-	// Create a new evaluation
-	now := time.Now().UnixNano()
-	submittedEval := false
-	var eval *structs.Evaluation
-
 	// Set the submit time
+	now := time.Now().UnixNano()
 	args.Job.SubmitTime = now
 
 	// If the job is periodic or parameterized, we don't create an eval.
@@ -315,7 +320,7 @@ func (j *Job) Register(args *structs.JobRegisterRequest, reply *structs.JobRegis
 			evalPriority = args.EvalPriority
 		}
 
-		eval = &structs.Evaluation{
+		args.Eval = &structs.Evaluation{
 			ID:          uuid.Generate(),
 			Namespace:   args.RequestNamespace(),
 			Priority:    evalPriority,
@@ -326,7 +331,7 @@ func (j *Job) Register(args *structs.JobRegisterRequest, reply *structs.JobRegis
 			CreateTime:  now,
 			ModifyTime:  now,
 		}
-		reply.EvalID = eval.ID
+		reply.EvalID = args.Eval.ID
 	}
 
 	// Check if the job has changed at all
@@ -334,79 +339,64 @@ func (j *Job) Register(args *structs.JobRegisterRequest, reply *structs.JobRegis
 	if err != nil {
 		return err
 	}
+	// We know the job isn't nil, so if the spec hasn't changed,
+	// there is an existing job.
+	if !specChanged {
+		reply.JobModifyIndex = existingJob.ModifyIndex
 
-	if existingJob == nil || specChanged {
-
-		if eval != nil {
-			args.Eval = eval
-			submittedEval = true
+		// Force an eval for service/batch jobs. This is intentional
+		// behavior to allow triggering of evaluations via re-registering
+		// similar to `nomad job eval`.
+		if args.Eval != nil {
+			update := &structs.EvalUpdateRequest{
+				Evals:        []*structs.Evaluation{args.Eval},
+				WriteRequest: structs.WriteRequest{Region: args.Region},
+			}
+			_, evalIndex, err := j.srv.raftApply(structs.EvalUpdateRequestType, update)
+			if err != nil {
+				j.logger.Error("eval create failed", "error", err, "method", "register")
+				return err
+			}
+			reply.EvalCreateIndex = evalIndex
+			reply.Index = evalIndex
+		} else {
+			reply.Index = existingJob.ModifyIndex
 		}
+		return nil
+	}
 
-		// Pre-register a deployment if necessary.
-		args.Deployment = j.multiregionCreateDeployment(job, eval)
+	// Pre-register a deployment if necessary.
+	args.Deployment = j.multiregionCreateDeployment(job, args.Eval)
+	// Commit this update via Raft
+	_, index, err := j.srv.raftApply(structs.JobRegisterRequestType, args)
+	if err != nil {
+		j.logger.Error("registering job failed", "error", err)
+		return err
+	}
 
-		// Commit this update via Raft
-		_, index, err := j.srv.raftApply(structs.JobRegisterRequestType, args)
-		if err != nil {
-			j.logger.Error("registering job failed", "error", err)
-			return err
-		}
+	// Populate the reply with job information
+	reply.JobModifyIndex = index
+	reply.Index = index
 
-		// Populate the reply with job information
-		reply.JobModifyIndex = index
-		reply.Index = index
-
-		if submittedEval {
-			reply.EvalCreateIndex = index
-		}
-
-	} else {
-		reply.JobModifyIndex = existingJob.JobModifyIndex
+	if args.Eval != nil {
+		reply.EvalCreateIndex = index
 	}
 
 	// used for multiregion start
 	args.Job.JobModifyIndex = reply.JobModifyIndex
 
-	if eval == nil {
-		// For dispatch jobs we return early, so we need to drop regions
-		// here rather than after eval for deployments is kicked off
-		err = j.multiregionDrop(args, reply)
-		if err != nil {
-			return err
-		}
-		return nil
-	}
-
-	if !submittedEval {
-		eval.JobModifyIndex = reply.JobModifyIndex
-		update := &structs.EvalUpdateRequest{
-			Evals:        []*structs.Evaluation{eval},
-			WriteRequest: structs.WriteRequest{Region: args.Region},
-		}
-
-		// Commit this evaluation via Raft
-		// There is a risk of partial failure where the JobRegister succeeds
-		// but that the EvalUpdate does not, before 0.12.1
-		_, evalIndex, err := j.srv.raftApply(structs.EvalUpdateRequestType, update)
-		if err != nil {
-			j.logger.Error("eval create failed", "error", err, "method", "register")
-			return err
-		}
-
-		reply.EvalCreateIndex = evalIndex
-		reply.Index = evalIndex
-	}
-
 	// Kick off a multiregion deployment (enterprise only).
 	if isRunner {
+		// This will skip running deployments for jobs that are not
+		// eligible to be run as deployments.
 		err = j.multiregionStart(args, reply)
 		if err != nil {
 			return err
 		}
 		// We drop any unwanted regions only once we know all jobs have
-		// been registered and we've kicked off the deployment. This keeps
-		// dropping regions close in semantics to dropping task groups in
-		// single-region deployments
+		// been registered and we've kicked off the deployment (if applicable).
+		// This keeps dropping regions close in semantics to dropping task
+		// groups in single-region deployments
 		err = j.multiregionDrop(args, reply)
 		if err != nil {
 			return err
@@ -570,9 +560,15 @@ func (j *Job) Revert(args *structs.JobRevertRequest, reply *structs.JobRegisterR
 	defer metrics.MeasureSince([]string{"nomad", "job", "revert"}, time.Now())
 
 	// Check for submit-job permissions
-	if aclObj, err := j.srv.ResolveACL(args); err != nil {
+	aclObj, err := j.srv.ResolveACL(args)
+	if err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(args.RequestNamespace(), acl.NamespaceCapabilitySubmitJob) {
+	}
+
+	if !aclObj.AllowNsOpAnyOf(args.RequestNamespace(),
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityRevertJob,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -632,7 +628,8 @@ func (j *Job) Revert(args *structs.JobRevertRequest, reply *structs.JobRegisterR
 	}
 
 	// Register the version.
-	return j.Register(reg, reply)
+	allowedPermissions := []string{acl.NamespaceCapabilityRevertJob}
+	return j.doRegister(aclObj, allowedPermissions, reg, reply)
 }
 
 // Stable is used to mark the job version as stable
@@ -650,7 +647,10 @@ func (j *Job) Stable(args *structs.JobStabilityRequest, reply *structs.JobStabil
 	// Check for read-job permissions
 	if aclObj, err := j.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(args.RequestNamespace(), acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(args.RequestNamespace(),
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityStableJob,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -701,7 +701,10 @@ func (j *Job) Evaluate(args *structs.JobEvaluateRequest, reply *structs.JobRegis
 	// Check for submit-job permissions
 	if aclObj, err := j.srv.ResolveACL(args); err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(args.RequestNamespace(), acl.NamespaceCapabilitySubmitJob) {
+	} else if !aclObj.AllowNsOpAnyOf(args.RequestNamespace(),
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityEvaluateJob,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -800,9 +803,17 @@ func (j *Job) Deregister(args *structs.JobDeregisterRequest, reply *structs.JobD
 	defer metrics.MeasureSince([]string{"nomad", "job", "deregister"}, time.Now())
 
 	// Check for submit-job permissions
-	if aclObj, err := j.srv.ResolveACL(args); err != nil {
+	aclObj, err := j.srv.ResolveACL(args)
+	if err != nil {
 		return err
-	} else if !aclObj.AllowNsOp(args.RequestNamespace(), acl.NamespaceCapabilitySubmitJob) {
+	}
+
+	permissionsCheck := []string{acl.NamespaceCapabilitySubmitJob, acl.NamespaceCapabilityPurgeJob}
+	if !args.Purge {
+		permissionsCheck = append(permissionsCheck, acl.NamespaceCapabilityDeregisterJob)
+	}
+
+	if !aclObj.AllowNsOpAnyOf(args.RequestNamespace(), permissionsCheck...) {
 		return structs.ErrPermissionDenied
 	}
 
@@ -1793,7 +1804,10 @@ func (j *Job) Plan(args *structs.JobPlanRequest, reply *structs.JobPlanResponse)
 	if aclObj, err := j.srv.ResolveACL(args); err != nil {
 		return err
 	} else {
-		if !aclObj.AllowNsOp(args.RequestNamespace(), acl.NamespaceCapabilitySubmitJob) {
+		if !aclObj.AllowNsOpAnyOf(args.RequestNamespace(),
+			acl.NamespaceCapabilitySubmitJob,
+			acl.NamespaceCapabilityPlanJob,
+		) {
 			return structs.ErrPermissionDenied
 		}
 		// Check if override is set and we do not have permissions
@@ -2045,40 +2059,24 @@ func (j *Job) Dispatch(args *structs.JobDispatchRequest, reply *structs.JobDispa
 		return err
 	}
 
-	// Avoid creating new dispatched jobs for retry requests, by using the idempotency token
+	// Avoid creating new dispatched jobs for retried requests, by using the
+	// idempotency token
 	if args.IdempotencyToken != "" {
-		// Fetch all jobs that match the parameterized job ID prefix
-		iter, err := snap.JobsByIDPrefix(ws, parameterizedJob.Namespace, parameterizedJob.ID, state.SortDefault)
+		found, err := snap.CheckIdempotencyToken(
+			parameterizedJob.Namespace, parameterizedJob.ID, args.IdempotencyToken)
 		if err != nil {
 			const errMsg = "failed to retrieve jobs for idempotency check"
 			j.logger.Error(errMsg, "error", err)
 			return fmt.Errorf(errMsg)
 		}
-
-		// Iterate
-		for {
-			raw := iter.Next()
-			if raw == nil {
-				break
-			}
-
-			// Ensure the parent ID is an exact match
-			existingJob := raw.(*structs.Job)
-			if existingJob.ParentID != parameterizedJob.ID {
-				continue
-			}
-
-			// Idempotency tokens match
-			if existingJob.DispatchIdempotencyToken == args.IdempotencyToken {
-				// The existing job has not yet been garbage collected.
-				// Registering a new job would violate the idempotency token.
-				// Return the existing job.
-				reply.JobCreateIndex = existingJob.CreateIndex
-				reply.DispatchedJobID = existingJob.ID
-				reply.Index = existingJob.ModifyIndex
-
-				return nil
-			}
+		if found != nil {
+			// The existing job has not yet been garbage collected. Registering
+			// a new job would violate the idempotency token. Return the ID and
+			// index of the existing job.
+			reply.JobCreateIndex = found.CreateIndex
+			reply.DispatchedJobID = found.ID
+			reply.Index = found.ModifyIndex
+			return nil
 		}
 	}
 
@@ -2420,7 +2418,10 @@ func (j *Job) TagVersion(args *structs.JobApplyTagRequest, reply *structs.JobTag
 	if err != nil {
 		return err
 	}
-	if !aclObj.AllowNsOp(args.RequestNamespace(), acl.NamespaceCapabilitySubmitJob) {
+	if !aclObj.AllowNsOpAnyOf(args.RequestNamespace(),
+		acl.NamespaceCapabilitySubmitJob,
+		acl.NamespaceCapabilityTagJobVersion,
+	) {
 		return structs.ErrPermissionDenied
 	}
 
