@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package structs
@@ -190,10 +190,6 @@ func (a *Allocation) Sanitize() *Allocation {
 		return nil
 	}
 
-	if a.SignedIdentities == nil {
-		return a
-	}
-
 	clean := a.Copy()
 	clean.SignedIdentities = nil
 	return clean
@@ -454,7 +450,7 @@ func (a *Allocation) NextRescheduleTime() (time.Time, bool) {
 
 	if (a.DesiredStatus == AllocDesiredStatusStop && !a.LastRescheduleFailed()) ||
 		(!isRescheduledBatch && a.ClientStatus != AllocClientStatusFailed && a.ClientStatus != AllocClientStatusLost) ||
-		failTime.IsZero() || reschedulePolicy == nil {
+		failTime.IsZero() {
 		return time.Time{}, false
 	}
 
@@ -486,16 +482,6 @@ func (a *Allocation) NextRescheduleTimeByTime(t time.Time) (time.Time, bool) {
 	return a.nextRescheduleTime(t, reschedulePolicy)
 }
 
-func (a *Allocation) RescheduleTimeOnDisconnect(now time.Time) (time.Time, bool) {
-	tg := a.Job.LookupTaskGroup(a.TaskGroup)
-	if tg == nil || tg.Disconnect == nil || tg.Disconnect.Replace == nil {
-		// Kept to maintain backwards compatibility with behavior prior to 1.8.0
-		return a.NextRescheduleTimeByTime(now)
-	}
-
-	return now, *tg.Disconnect.Replace
-}
-
 // ShouldClientStop tests an alloc for StopAfterClient on the Disconnect configuration
 func (a *Allocation) ShouldClientStop() bool {
 	tg := a.Job.LookupTaskGroup(a.TaskGroup)
@@ -550,7 +536,7 @@ func (a *Allocation) DisconnectTimeout(now time.Time) time.Time {
 
 	tg := a.Job.LookupTaskGroup(a.TaskGroup)
 
-	timeout := tg.GetDisconnectLostTimeout()
+	timeout := tg.GetDisconnectLostAfter()
 	if timeout == 0 {
 		return now
 	}
@@ -558,35 +544,17 @@ func (a *Allocation) DisconnectTimeout(now time.Time) time.Time {
 	return now.Add(timeout)
 }
 
-// SupportsDisconnectedClients determines whether both the server and the task group
-// are configured to allow the allocation to reconnect after network connectivity
-// has been lost and then restored.
-func (a *Allocation) SupportsDisconnectedClients(serverSupportsDisconnectedClients bool) bool {
-	if !serverSupportsDisconnectedClients {
-		return false
-	}
-
-	if a.Job != nil {
-		tg := a.Job.LookupTaskGroup(a.TaskGroup)
-		if tg != nil {
-			return tg.GetDisconnectLostTimeout() != 0
-		}
-	}
-
-	return false
-}
-
-// PreventReplaceOnDisconnect determines if an alloc allows to have a replacement
+// ReplaceOnDisconnect determines if an alloc can be replaced
 // when Disconnected.
-func (a *Allocation) PreventReplaceOnDisconnect() bool {
+func (a *Allocation) ReplaceOnDisconnect() bool {
 	if a.Job != nil {
 		tg := a.Job.LookupTaskGroup(a.TaskGroup)
 		if tg != nil {
-			return !tg.Replace()
+			return tg.Replace()
 		}
 	}
 
-	return false
+	return true
 }
 
 // NextDelay returns a duration after which the allocation can be rescheduled.
@@ -802,12 +770,7 @@ func (a *Allocation) Expired(now time.Time) bool {
 		return false
 	}
 
-	timeout := tg.GetDisconnectLostTimeout()
-	if timeout == 0 && tg.Replace() {
-		return false
-	}
-
-	expiry := lastUnknown.Add(timeout)
+	expiry := lastUnknown.Add(tg.GetDisconnectLostAfter())
 	return expiry.Sub(now) <= 0
 }
 
@@ -815,12 +778,18 @@ func (a *Allocation) Expired(now time.Time) bool {
 // transitioned into the unknown client status.
 func (a *Allocation) LastUnknown() time.Time {
 	var lastUnknown time.Time
+	foundUnknown := false
 
-	for _, s := range a.AllocStates {
-		if s.Field == AllocStateFieldClientStatus &&
-			s.Value == AllocClientStatusUnknown {
-			if lastUnknown.IsZero() || lastUnknown.Before(s.Time) {
+	// Traverse backwards
+	for i := len(a.AllocStates) - 1; i >= 0; i-- {
+		s := a.AllocStates[i]
+		if s.Field == AllocStateFieldClientStatus {
+			if s.Value == AllocClientStatusUnknown {
 				lastUnknown = s.Time
+				foundUnknown = true
+			} else if foundUnknown {
+				// We found the transition from non-unknown to unknown
+				break
 			}
 		}
 	}
