@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2015, 2025
 // SPDX-License-Identifier: BUSL-1.1
 
 package structs
@@ -124,6 +124,17 @@ func (p *PlanBuilder) SubmitPlan(plan *structs.Plan) (*structs.PlanResult, State
 
 	snap, _ := p.State.Snapshot()
 
+	// try to pull the job from the state if the plan doesn't already contain any
+	// job information
+	job := plan.Job
+	if job == nil {
+		var err error
+		job, err = snap.JobByID(nil, plan.JobInfo.Namespace, plan.JobInfo.ID)
+		if err != nil {
+			return result, nil, err
+		}
+	}
+
 	// make sure these are denormalized the same way they would be in the real
 	// plan applier
 	allocsStopped := make([]*structs.AllocationDiff, 0, len(result.NodeUpdate))
@@ -148,7 +159,7 @@ func (p *PlanBuilder) SubmitPlan(plan *structs.Plan) (*structs.PlanResult, State
 		AllocsStopped:     allocsStopped,
 		AllocsUpdated:     allocsUpdated,
 		AllocsPreempted:   allocsPreempted,
-		Job:               plan.Job,
+		Job:               job,
 		Deployment:        plan.Deployment,
 		DeploymentUpdates: plan.DeploymentUpdates,
 		EvalID:            plan.EvalID,
@@ -159,8 +170,7 @@ func (p *PlanBuilder) SubmitPlan(plan *structs.Plan) (*structs.PlanResult, State
 	}
 
 	// Apply the full plan
-	err := p.State.UpsertPlanResults(structs.MsgTypeTestSetup, index, &req)
-	return result, nil, err
+	return result, nil, p.State.UpsertPlanResults(structs.MsgTypeTestSetup, index, &req)
 }
 
 func updateCreateTimestamp(allocations []*structs.Allocation, now int64) {
