@@ -1,4 +1,4 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright IBM Corp. 2013, 2025
 // SPDX-License-Identifier: MPL-2.0
 
 package memberlist
@@ -15,7 +15,7 @@ import (
 	"sync/atomic"
 	"time"
 
-	"github.com/hashicorp/go-metrics/compat"
+	metrics "github.com/hashicorp/go-metrics/compat"
 	"github.com/hashicorp/go-msgpack/v2/codec"
 )
 
@@ -234,23 +234,33 @@ func (m *Memberlist) streamListen() {
 
 // handleConn handles a single incoming stream connection from the transport.
 func (m *Memberlist) handleConn(conn net.Conn) {
-	defer conn.Close()
 	m.logger.Printf("[DEBUG] memberlist: Stream connection %s", LogConn(conn))
 
 	metrics.IncrCounterWithLabels([]string{"memberlist", "tcp", "accept"}, 1, m.metricLabels)
 
-	conn.SetDeadline(time.Now().Add(m.config.TCPTimeout))
+	if err := conn.SetDeadline(time.Now().Add(m.config.TCPTimeout)); err != nil {
+		m.logger.Printf("Err: Could not set the deadline: %s", err)
+	}
 
 	var (
 		streamLabel string
 		err         error
+		// Store the original conn, because the code below shadows it.
+		// If reading the label header from the stream fail, we should still close the connection.
+		origConn = conn
 	)
 	conn, streamLabel, err = RemoveLabelHeaderFromStream(conn)
 	if err != nil {
-		m.logger.Printf("[ERR] memberlist: failed to receive and remove the stream label header: %s %s", err, LogConn(conn))
+		m.logger.Printf("[ERR] memberlist: failed to receive and remove the stream label header: %s %s", err, LogConn(origConn))
+		_ = origConn.Close()
 		return
 	}
 
+	defer func() {
+		// Always close the wrapped connection, that we got after removing the label header.
+		_ = conn.Close()
+	}()
+
 	if m.config.SkipInboundLabelCheck {
 		if streamLabel != "" {
 			m.logger.Printf("[ERR] memberlist: unexpected double stream label header: %s", LogConn(conn))
@@ -707,7 +717,7 @@ func (m *Memberlist) ensureCanConnect(from net.Addr) error {
 
 	ip := net.ParseIP(host)
 	if ip == nil {
-		return fmt.Errorf("Cannot parse IP from %s", host)
+		return fmt.Errorf("cannot parse IP from %s", host)
 	}
 	return m.config.IPAllowed(ip)
 }
@@ -922,7 +932,9 @@ func (m *Memberlist) sendUserMsg(a Address, sendBuf []byte) error {
 	if err != nil {
 		return err
 	}
-	defer conn.Close()
+	defer func() {
+		_ = conn.Close()
+	}()
 
 	bufConn := bytes.NewBuffer(nil)
 	if err := bufConn.WriteByte(byte(userMsg)); err != nil {
@@ -930,11 +942,9 @@ func (m *Memberlist) sendUserMsg(a Address, sendBuf []byte) error {
 	}
 
 	header := userMsgHeader{UserMsgLen: len(sendBuf)}
-	hd := codec.MsgpackHandle{
-		BasicHandle: codec.BasicHandle{
-			TimeNotBuiltin: !m.config.MsgpackUseNewTimeFormat,
-		},
-	}
+	hd := codec.MsgpackHandle{}
+	hd.TimeNotBuiltin = !m.config.MsgpackUseNewTimeFormat
+
 	enc := codec.NewEncoder(bufConn, &hd)
 	if err := enc.Encode(&header); err != nil {
 		return err
@@ -958,7 +968,9 @@ func (m *Memberlist) sendAndReceiveState(a Address, join bool) ([]pushNodeState,
 	if err != nil {
 		return nil, nil, err
 	}
-	defer conn.Close()
+	defer func() {
+		_ = conn.Close()
+	}()
 	m.logger.Printf("[DEBUG] memberlist: Initiating push/pull sync with: %s %s", a.Name, conn.RemoteAddr())
 	metrics.IncrCounterWithLabels([]string{"memberlist", "tcp", "connect"}, 1, m.metricLabels)
 
@@ -967,7 +979,9 @@ func (m *Memberlist) sendAndReceiveState(a Address, join bool) ([]pushNodeState,
 		return nil, nil, err
 	}
 
-	conn.SetDeadline(time.Now().Add(m.config.TCPTimeout))
+	if err := conn.SetDeadline(time.Now().Add(m.config.TCPTimeout)); err != nil {
+		m.logger.Printf("Err: Could not set the deadline: %s", err)
+	}
 	msgType, bufConn, dec, err := m.readStream(conn, m.config.Label)
 	if err != nil {
 		return nil, nil, err
@@ -995,7 +1009,9 @@ func (m *Memberlist) sendAndReceiveState(a Address, join bool) ([]pushNodeState,
 // sendLocalState is invoked to send our local state over a stream connection.
 func (m *Memberlist) sendLocalState(conn net.Conn, join bool, streamLabel string) error {
 	// Setup a deadline
-	conn.SetDeadline(time.Now().Add(m.config.TCPTimeout))
+	if err := conn.SetDeadline(time.Now().Add(m.config.TCPTimeout)); err != nil {
+		m.logger.Printf("Err: Could not set the deadline: %s", err)
+	}
 
 	// Prepare the local node state
 	m.nodeLock.RLock()
@@ -1117,7 +1133,7 @@ func (m *Memberlist) decryptRemoteState(bufConn io.Reader, streamLabel string) (
 	metrics.AddSampleWithLabels([]string{"memberlist", "size", "remote"}, float32(moreBytes), m.metricLabels)
 
 	if moreBytes > maxPushStateBytes {
-		return nil, fmt.Errorf("Remote node state is larger than limit (%d)", moreBytes)
+		return nil, fmt.Errorf("remote node state is larger than limit (%d)", moreBytes)
 
 	}
 
@@ -1166,7 +1182,7 @@ func (m *Memberlist) readStream(conn net.Conn, streamLabel string) (messageType,
 	if msgType == encryptMsg {
 		if !m.config.EncryptionEnabled() {
 			return 0, nil, nil,
-				fmt.Errorf("Remote state is encrypted and encryption is not configured")
+				fmt.Errorf("remote state is encrypted and encryption is not configured")
 		}
 
 		plain, err := m.decryptRemoteState(bufConn, streamLabel)
@@ -1179,7 +1195,7 @@ func (m *Memberlist) readStream(conn net.Conn, streamLabel string) (messageType,
 		bufConn = bytes.NewReader(plain[1:])
 	} else if m.config.EncryptionEnabled() && m.config.GossipVerifyIncoming {
 		return 0, nil, nil,
-			fmt.Errorf("Encryption is configured but remote state is not encrypted")
+			fmt.Errorf("encryption is configured but remote state is not encrypted")
 	}
 
 	// Get the msgPack decoders
@@ -1235,7 +1251,7 @@ func (m *Memberlist) readRemoteState(bufConn io.Reader, dec *codec.Decoder) (boo
 		bytes, err := io.ReadAtLeast(bufConn, userBuf, header.UserStateLen)
 		if err == nil && bytes != header.UserStateLen {
 			err = fmt.Errorf(
-				"Failed to read full user state (%d / %d)",
+				"failed to read full user state (%d / %d)",
 				bytes, header.UserStateLen)
 		}
 		if err != nil {
@@ -1308,7 +1324,7 @@ func (m *Memberlist) readUserMsg(bufConn io.Reader, dec *codec.Decoder) error {
 		bytes, err := io.ReadAtLeast(bufConn, userBuf, header.UserMsgLen)
 		if err == nil && bytes != header.UserMsgLen {
 			err = fmt.Errorf(
-				"Failed to read full user message (%d / %d)",
+				"failed to read full user message (%d / %d)",
 				bytes, header.UserMsgLen)
 		}
 		if err != nil {
@@ -1333,7 +1349,7 @@ func (m *Memberlist) sendPingAndWaitForAck(a Address, ping ping, deadline time.T
 		return false, errNodeNamesAreRequired
 	}
 
-	conn, err := m.transport.DialAddressTimeout(a, deadline.Sub(time.Now()))
+	conn, err := m.transport.DialAddressTimeout(a, time.Until(deadline))
 	if err != nil {
 		// If the node is actually dead we expect this to fail, so we
 		// shouldn't spam the logs with it. After this point, errors
@@ -1341,8 +1357,10 @@ func (m *Memberlist) sendPingAndWaitForAck(a Address, ping ping, deadline time.T
 		// get propagated up.
 		return false, nil
 	}
-	defer conn.Close()
-	conn.SetDeadline(deadline)
+	defer func() {
+		_ = conn.Close()
+	}()
+	_ = conn.SetDeadline(deadline)
 
 	out, err := encode(pingMsg, &ping, m.config.MsgpackUseNewTimeFormat)
 	if err != nil {
@@ -1359,7 +1377,7 @@ func (m *Memberlist) sendPingAndWaitForAck(a Address, ping ping, deadline time.T
 	}
 
 	if msgType != ackRespMsg {
-		return false, fmt.Errorf("Unexpected msgType (%d) from ping %s", msgType, LogConn(conn))
+		return false, fmt.Errorf("unexpected msgType (%d) from ping %s", msgType, LogConn(conn))
 	}
 
 	var ack ackResp
@@ -1368,7 +1386,7 @@ func (m *Memberlist) sendPingAndWaitForAck(a Address, ping ping, deadline time.T
 	}
 
 	if ack.SeqNo != ping.SeqNo {
-		return false, fmt.Errorf("Sequence number from ack (%d) doesn't match ping (%d)", ack.SeqNo, ping.SeqNo)
+		return false, fmt.Errorf("sequence number from ack (%d) doesn't match ping (%d)", ack.SeqNo, ping.SeqNo)
 	}
 
 	return true, nil
